@@ -23,6 +23,8 @@ See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/command
 for examples and usage instructions.
 """
 
+import sys
+
 from translate.convert import convert
 from translate.storage import ini, po
 
@@ -38,10 +40,8 @@ class ini2po(object):
                  blank_msgstr=False, duplicate_style="msgctxt",
                  dialect="default"):
         """Initialize the converter."""
-        import sys
-        if sys.version_info[0] == 3:
-            print("Translate Toolkit doesn't yet support converting from INI in "
-                  "Python 3.")
+        if ini.INIConfig is None:
+            print("Missing iniparse library!")
             sys.exit()
 
         self.blank_msgstr = blank_msgstr
