@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2002-2008 Zuza Software Foundation
@@ -24,6 +23,7 @@ See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/command
 for examples and usage instructions.
 """
 
+import re
 import six
 
 from translate.convert import convert
@@ -76,10 +76,16 @@ class rephp(object):
         elif line.strip()[:2] == '//' or line.strip()[:2] == '/*':
             returnline = quote.rstripeol(line) + eol
         elif line.lower().replace(" ", "").find('array(') != -1:
-            self.inarray = True
-            self.prename = line[:line.find('=')].strip() + "->"
-            self.equaldel = "=>"
-            self.enddel = ","
+            eqpos = line.find('=')
+            # If this is a nested array.
+            if self.inarray:
+                self.prename += line[:eqpos].strip() + "->"
+            else:
+                self.inarray = True
+                if eqpos != -1:
+                    self.prename += line[:eqpos].strip() + "->"
+                self.equaldel = "=>"
+                self.enddel = ","
             returnline = quote.rstripeol(line) + eol
         elif self.inarray and line.find(');') != -1:
             self.inarray = False
@@ -87,6 +93,9 @@ class rephp(object):
             self.enddel = ";"
             self.prename = ""
             returnline = quote.rstripeol(line) + eol
+        elif self.inarray and line.find('),') != -1:
+            self.prename = re.sub(r'[^>]+->$', '', self.prename)
+            returnline = quote.rstripeol(line) + eol
         else:
             line = quote.rstripeol(line)
             equalspos = line.find(self.equaldel)
@@ -127,9 +136,6 @@ class rephp(object):
                     value = php.phpencode(value, self.quotechar)
                     self.inecho = False
 
-                    if isinstance(value, bytes):
-                        value = value.decode('utf8')
-
                     params = {
                         "key": key,
                         "pre": prespace,
