@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2004-2006 Zuza Software Foundation
@@ -69,7 +68,7 @@ def convertpo(inputfile, outputfile, templatefile, context):
         return 0
     convertor = po2ts()
     outputstring = convertor.convertstore(inputstore, templatefile, context)
-    outputfile.write(outputstring)
+    outputfile.write(outputstring.encode('utf-8'))
     return 1
 
 
