@@ -316,14 +316,15 @@ Some other text
 <!ENTITY useAutoScroll.accesskey         "a">'''
         pofile = self.dtd2po(dtdlanguage, dtdtemplate)
         print(pofile)
-        assert pofile.units[1].target == "使用自動捲動(&Autoscrolling)"
+        expected_target = "使用自動捲動(&Autoscrolling)".decode('utf-8')
+        assert pofile.units[1].target == expected_target
         # We assume that accesskeys with no associated key should be done as follows "XXXX (&A)"
         # TODO - check that we can unfold this from PO -> DTD
         dtdlanguage = '''<!ENTITY useAutoScroll.label             "使用自動捲動">
 <!ENTITY useAutoScroll.accesskey         "a">'''
         pofile = self.dtd2po(dtdlanguage, dtdtemplate)
         print(pofile)
-        assert pofile.units[1].target == "使用自動捲動 (&A)"
+        assert pofile.units[1].target == "使用自動捲動 (&A)".decode('utf-8')
 
     def test_exclude_entity_includes(self):
         """test that we don't turn an include into a translatable string"""
