@@ -1,5 +1,5 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
+from __future__ import print_function
 
 import warnings
 
@@ -10,7 +10,7 @@ from translate.misc import wStringIO
 from translate.storage import dtd, po
 
 
-class TestPO2DTD:
+class TestPO2DTD(object):
 
     def setup_method(self, method):
         warnings.resetwarnings()
@@ -43,7 +43,7 @@ class TestPO2DTD:
         templatefile = wStringIO.StringIO(dtdtemplate)
         assert po2dtd.convertdtd(inputfile, outputfile, templatefile,
                                  remove_untranslated=remove_untranslated)
-        return outputfile.getvalue()
+        return outputfile.getvalue().decode('utf-8')
 
     def roundtripsource(self, dtdsource):
         """converts dtd source to po and back again, returning the resulting source"""
@@ -56,7 +56,7 @@ class TestPO2DTD:
         dtdtemplatefile = wStringIO.StringIO(dtdsource)
         dtdoutputfile = wStringIO.StringIO()
         po2dtd.convertdtd(poinputfile, dtdoutputfile, dtdtemplatefile)
-        dtdresult = dtdoutputfile.getvalue()
+        dtdresult = dtdoutputfile.getvalue().decode('utf-8')
         print_string = "Original DTD:\n%s\n\nPO version:\n%s\n\n"
         print_string = print_string + "Output DTD:\n%s\n################"
         print(print_string % (dtdsource, posource, dtdresult))
@@ -91,15 +91,15 @@ class TestPO2DTD:
         """tests that po lines are joined seamlessly (bug 16)"""
         multilinepo = '''#: pref.menuPath\nmsgid ""\n"<span>Tools &gt; Options</"\n"span>"\nmsgstr ""\n'''
         dtdfile = self.po2dtd(multilinepo)
-        dtdsource = str(dtdfile)
-        assert "</span>" in dtdsource
+        dtdsource = bytes(dtdfile)
+        assert b"</span>" in dtdsource
 
     def test_escapedstr(self):
         """tests that \n in msgstr is escaped correctly in dtd"""
         multilinepo = '''#: pref.menuPath\nmsgid "Hello\\nEveryone"\nmsgstr "Good day\\nAll"\n'''
         dtdfile = self.po2dtd(multilinepo)
-        dtdsource = str(dtdfile)
-        assert "Good day\nAll" in dtdsource
+        dtdsource = bytes(dtdfile)
+        assert b"Good day\nAll" in dtdsource
 
     def test_missingaccesskey(self):
         """tests that proper warnings are given if access key is missing"""
@@ -111,24 +111,25 @@ msgstr "Dimpled Ring"
         simpledtd = '''<!ENTITY simple.label "Simple String">
 <!ENTITY simple.accesskey "S">'''
         warnings.simplefilter("error")
-        assert pytest.raises(Warning, self.merge2dtd, simpledtd, simplepo)
+        with pytest.raises(Warning):
+            self.merge2dtd(simpledtd, simplepo)
 
     def test_accesskeycase(self):
         """tests that access keys come out with the same case as the original, regardless"""
         simplepo_template = '''#: simple.label\n#: simple.accesskey\nmsgid "%s"\nmsgstr "%s"\n'''
         simpledtd_template = '''<!ENTITY simple.label "Simple %s">\n<!ENTITY simple.accesskey "%s">'''
         possibilities = [
-                #(en label, en akey, en po, af po, af label, expected af akey)
-                ("Sis", "S", "&Sis", "&Sies", "Sies", "S"),
-                ("Sis", "s", "Si&s", "&Sies", "Sies", "S"),
-                ("Sis", "S", "&Sis", "Sie&s", "Sies", "s"),
-                ("Sis", "s", "Si&s", "Sie&s", "Sies", "s"),
-                # untranslated strings should have the casing of the source
-                ("Sis", "S", "&Sis", "", "Sis", "S"),
-                ("Sis", "s", "Si&s", "", "Sis", "s"),
-                ("Suck", "S", "&Suck", "", "Suck", "S"),
-                ("Suck", "s", "&Suck", "", "Suck", "s"),
-                ]
+            #(en label, en akey, en po, af po, af label, expected af akey)
+            ("Sis", "S", "&Sis", "&Sies", "Sies", "S"),
+            ("Sis", "s", "Si&s", "&Sies", "Sies", "S"),
+            ("Sis", "S", "&Sis", "Sie&s", "Sies", "s"),
+            ("Sis", "s", "Si&s", "Sie&s", "Sies", "s"),
+            # untranslated strings should have the casing of the source
+            ("Sis", "S", "&Sis", "", "Sis", "S"),
+            ("Sis", "s", "Si&s", "", "Sis", "s"),
+            ("Suck", "S", "&Suck", "", "Suck", "S"),
+            ("Suck", "s", "&Suck", "", "Suck", "s"),
+        ]
         for (en_label, en_akey, po_source, po_target, target_label, target_akey) in possibilities:
             simplepo = simplepo_template % (po_source, po_target)
             simpledtd = simpledtd_template % (en_label, en_akey)
@@ -149,25 +150,6 @@ msgstr "Dimpled Ring"
                 dtdfile.makeindex()
                 assert dtd.unquotefromdtd(dtdfile.id_index["simple.%s" % accesskey].definition) == "a"
 
-    def test_ampersandfix(self):
-        """tests that invalid ampersands are fixed in the dtd"""
-        simplestring = '''#: simple.string\nmsgid "Simple String"\nmsgstr "Dimpled &Ring"\n'''
-        dtdfile = self.po2dtd(simplestring)
-        dtdsource = str(dtdfile)
-        assert "Dimpled Ring" in dtdsource
-
-        po_snippet = r'''#: searchIntegration.label
-#: searchIntegration.accesskey
-msgid "Allow &searchIntegration.engineName; to &search messages"
-msgstr "&searchIntegration.engineName; &ileti aramasına izin ver"
-'''
-        dtd_snippet = r'''<!ENTITY searchIntegration.accesskey      "s">
-<!ENTITY searchIntegration.label       "Allow &searchIntegration.engineName; to search messages">'''
-        dtdfile = self.merge2dtd(dtd_snippet, po_snippet)
-        dtdsource = str(dtdfile)
-        print(dtdsource)
-        assert '"&searchIntegration.engineName; ileti aramasına izin ver"' in dtdsource
-
     def test_accesskey_missing(self):
         """tests that missing ampersands use the source accesskey"""
         po_snippet = r'''#: key.label
@@ -178,7 +160,7 @@ msgstr "Ileti"
         dtd_snippet = r'''<!ENTITY key.accesskey      "S">
 <!ENTITY key.label       "Ileti">'''
         dtdfile = self.merge2dtd(dtd_snippet, po_snippet)
-        dtdsource = str(dtdfile)
+        dtdsource = bytes(dtdfile).decode('utf-8')
         print(dtdsource)
         assert '"Ileti"' in dtdsource
         assert '""' not in dtdsource
@@ -196,12 +178,12 @@ msgstr "Lig en Kleur"
         dtd_snippet = r'''<!ENTITY key.accesskey      "L">
 <!ENTITY key.label       "Colour &amp; Light">'''
         dtdfile = self.merge2dtd(dtd_snippet, po_snippet)
-        dtdsource = str(dtdfile)
+        dtdsource = bytes(dtdfile).decode('utf-8')
         print(dtdsource)
         assert '"Lig en Kleur"' in dtdsource
         assert '"L"' in dtdsource
 
-    def test_accesskey_and_amp_case_no_amp(self):
+    def test_accesskey_and_amp_source_no_amp_in_target(self):
         """tests that accesskey and &amp; can work together
 
         If present we use the target accesskey"""
@@ -213,7 +195,7 @@ msgstr "Lig en &Kleur"
         dtd_snippet = r'''<!ENTITY key.accesskey      "L">
 <!ENTITY key.label       "Colour &amp; Light">'''
         dtdfile = self.merge2dtd(dtd_snippet, po_snippet)
-        dtdsource = str(dtdfile)
+        dtdsource = bytes(dtdfile).decode('utf-8')
         print(dtdsource)
         assert '"Lig en Kleur"' in dtdsource
         assert '"K"' in dtdsource
@@ -231,38 +213,56 @@ msgstr "Lig & &Kleur"
         dtd_snippet = r'''<!ENTITY key.accesskey      "L">
 <!ENTITY key.label       "Colour &amp; Light">'''
         dtdfile = self.merge2dtd(dtd_snippet, po_snippet)
-        dtdsource = str(dtdfile)
+        dtdsource = bytes(dtdfile).decode('utf-8')
         print(dtdsource)
         assert '"Lig &amp; Kleur"' in dtdsource
         assert '"K"' in dtdsource
 
+    def test_accesskey_and_amp_case_amp_no_accesskey(self):
+        """tests that accesskey and &amp; can work together
+
+        If present both & (and) and a no marker then we use the correct source
+        accesskey"""
+        po_snippet = r'''#: key.label
+#: key.accesskey
+msgid "Colour & &Light"
+msgstr "Lig & Kleur"
+'''
+        dtd_snippet = r'''<!ENTITY key.accesskey      "L">
+<!ENTITY key.label       "Colour &amp; Light">'''
+        dtdfile = self.merge2dtd(dtd_snippet, po_snippet)
+        dtdsource = bytes(dtdfile).decode('utf-8')
+        print(dtdsource)
+        assert '"Lig &amp; Kleur"' in dtdsource
+        assert '"L"' in dtdsource
+
     def test_entities_two(self):
         """test the error ouput when we find two entities"""
         simplestring = '''#: simple.string second.string\nmsgid "Simple String"\nmsgstr "Dimpled Ring"\n'''
         dtdfile = self.po2dtd(simplestring)
-        dtdsource = str(dtdfile)
-        assert "CONVERSION NOTE - multiple entities" in dtdsource
+        dtdsource = bytes(dtdfile)
+        assert b"CONVERSION NOTE - multiple entities" in dtdsource
 
     def test_entities(self):
         """tests that entities are correctly idnetified in the dtd"""
         simplestring = '''#: simple.string\nmsgid "Simple String"\nmsgstr "Dimpled Ring"\n'''
         dtdfile = self.po2dtd(simplestring)
-        dtdsource = str(dtdfile)
-        assert dtdsource.startswith("<!ENTITY simple.string")
+        dtdsource = bytes(dtdfile)
+        assert dtdsource.startswith(b"<!ENTITY simple.string")
 
     def test_comments_translator(self):
         """tests for translator comments"""
         simplestring = '''# Comment1\n# Comment2\n#: simple.string\nmsgid "Simple String"\nmsgstr "Dimpled Ring"\n'''
         dtdfile = self.po2dtd(simplestring)
-        dtdsource = str(dtdfile)
-        assert dtdsource.startswith("<!-- Comment1 -->")
+        dtdsource = bytes(dtdfile)
+        assert dtdsource.startswith(b"<!-- Comment1 -->")
 
     def test_retains_hashprefix(self):
         """tests that hash prefixes in the dtd are retained"""
         hashpo = '''#: lang.version\nmsgid "__MOZILLA_LOCALE_VERSION__"\nmsgstr "__MOZILLA_LOCALE_VERSION__"\n'''
         hashdtd = '#expand <!ENTITY lang.version "__MOZILLA_LOCALE_VERSION__">\n'
         dtdfile = self.merge2dtd(hashdtd, hashpo)
-        regendtd = str(dtdfile)
+        regendtd = bytes(dtdfile).decode('utf-8')
         assert regendtd == hashdtd
 
     def test_convertdtd(self):
@@ -330,8 +330,8 @@ msgstr "simple string four"
 <!ENTITY simple.label3 "Simple string 3">
 '''
         newdtd = self.po2dtd(posource, remove_untranslated=True)
-        print(newdtd)
-        assert str(newdtd) == dtdexpected
+        print(bytes(newdtd))
+        assert bytes(newdtd).decode('utf-8') == dtdexpected
 
     def test_blank_source(self):
         """test removing of untranslated entries where source is blank"""
@@ -363,8 +363,8 @@ msgstr "Simple string 3"
         print(newdtd_with_template)
         assert newdtd_with_template == dtdexpected_with_template
         newdtd_no_template = self.po2dtd(posource, remove_untranslated=True)
-        print(newdtd_no_template)
-        assert str(newdtd_no_template) == dtdexpected_no_template
+        print(bytes(newdtd_no_template))
+        assert bytes(newdtd_no_template).decode('utf-8') == dtdexpected_no_template
 
     def test_newlines_escapes(self):
         """check that we can handle a \n in the PO file"""
@@ -372,8 +372,8 @@ msgstr "Simple string 3"
         dtdtemplate = '<!ENTITY  simple.label "A hard coded newline.\n">\n'
         dtdexpected = '''<!ENTITY  simple.label "Hart gekoeerde nuwe lyne\n">\n'''
         dtdfile = self.merge2dtd(dtdtemplate, posource)
-        print(dtdfile)
-        assert str(dtdfile) == dtdexpected
+        print(bytes(dtdfile))
+        assert bytes(dtdfile).decode('utf-8') == dtdexpected
 
     def test_roundtrip_simple(self):
         """checks that simple strings make it through a dtd->po->dtd roundtrip"""
@@ -436,12 +436,12 @@ msgstr "Simple string 3"
     def test_merging_entries_with_spaces_removed(self):
         """dtd2po removes pretty printed spaces, this tests that we can merge this back into the pretty printed dtd"""
         posource = '''#: simple.label\nmsgid "First line then "\n"next lines."\nmsgstr "Eerste lyne en dan volgende lyne."\n'''
-        dtdtemplate = '<!ENTITY simple.label "First line then\n' + \
-          '                                          next lines.">\n'
+        dtdtemplate = ('<!ENTITY simple.label "First line then\n'
+                       '                           next lines.">\n')
         dtdexpected = '<!ENTITY simple.label "Eerste lyne en dan volgende lyne.">\n'
         dtdfile = self.merge2dtd(dtdtemplate, posource)
-        print(dtdfile)
-        assert str(dtdfile) == dtdexpected
+        print(bytes(dtdfile))
+        assert bytes(dtdfile).decode('utf-8') == dtdexpected
 
     def test_preserving_spaces(self):
         """ensure that we preseve spaces between entity and value. Bug 1662"""
@@ -449,8 +449,8 @@ msgstr "Simple string 3"
         dtdtemplate = '<!ENTITY     simple.label         "One">\n'
         dtdexpected = '<!ENTITY     simple.label         "Een">\n'
         dtdfile = self.merge2dtd(dtdtemplate, posource)
-        print(dtdfile)
-        assert str(dtdfile) == dtdexpected
+        print(bytes(dtdfile))
+        assert bytes(dtdfile).decode('utf-8') == dtdexpected
 
     def test_preserving_spaces_after_value(self):
         """Preseve spaces after value. Bug 1662"""
@@ -459,22 +459,22 @@ msgstr "Simple string 3"
         dtdtemplate = '<!ENTITY simple.label "One" >\n'
         dtdexpected = '<!ENTITY simple.label "Een" >\n'
         dtdfile = self.merge2dtd(dtdtemplate, posource)
-        print(dtdfile)
-        assert str(dtdfile) == dtdexpected
+        print(bytes(dtdfile))
+        assert bytes(dtdfile).decode('utf-8') == dtdexpected
         # Space after >
         dtdtemplate = '<!ENTITY simple.label "One"> \n'
         dtdexpected = '<!ENTITY simple.label "Een"> \n'
         dtdfile = self.merge2dtd(dtdtemplate, posource)
         print(dtdfile)
-        assert str(dtdfile) == dtdexpected
+        assert bytes(dtdfile).decode('utf-8') == dtdexpected
 
     def test_comments(self):
         """test that we preserve comments, bug 351"""
         posource = '''#: name\nmsgid "Text"\nmsgstr "Teks"'''
         dtdtemplate = '''<!ENTITY name "%s">\n<!-- \n\nexample -->\n'''
         dtdfile = self.merge2dtd(dtdtemplate % "Text", posource)
-        print(dtdfile)
-        assert str(dtdfile) == dtdtemplate % "Teks"
+        print(bytes(dtdfile))
+        assert bytes(dtdfile).decode('utf-8') == dtdtemplate % "Teks"
 
     def test_duplicates(self):
         """test that we convert duplicates back correctly to their respective entries."""
@@ -504,8 +504,8 @@ msgstr "Dipukutshwayo3"
 <!ENTITY bookmarksButton.label "Dipukutshwayo3">
 '''
         dtdfile = self.merge2dtd(dtdtemplate, posource)
-        print(dtdfile)
-        assert str(dtdfile) == dtdexpected
+        print(bytes(dtdfile))
+        assert bytes(dtdfile).decode('utf-8') == dtdexpected
 
 
 class TestPO2DTDCommand(test_convert.TestConvertCommand, TestPO2DTD):
@@ -525,9 +525,9 @@ class TestPO2DTDCommand(test_convert.TestConvertCommand, TestPO2DTD):
         test_convert.TestConvertCommand.teardown_method(self, method)
         TestPO2DTD.teardown_method(self, method)
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--fuzzy")
         options = self.help_check(options, "--threshold=PERCENT")
