@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2010 Zuza Software Foundation
@@ -23,10 +22,14 @@
 .. seealso:: http://en.wikipedia.org/wiki/Sinhala_language
 """
 
+from __future__ import unicode_literals
+
 from translate.lang import common
 
 
 class si(common.Common):
     """This class represents Sinhala."""
 
-    ignoretests = ["startcaps", "simplecaps"]
+    ignoretests = {
+        'all': ["simplecaps", "startcaps"],
+    }
