@@ -27,6 +27,7 @@ take a look at PyLuceneIndexer1.py for the PyLucene v1.x interface
 
 import logging
 import os
+import six
 import time
 
 # try to import the PyLucene package (with the two possible names)
@@ -42,7 +43,7 @@ except ImportError:
     PyLucene.initVM(PyLucene.CLASSPATH)
     _COMPILER = 'jcc'
 
-import CommonIndexer
+from . import CommonIndexer
 
 
 UNNAMED_FIELD_NAME = "FieldWithoutAName"
@@ -81,8 +82,8 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
         """
         jvm = PyLucene.getVMEnv()
         jvm.attachCurrentThread()
-        super(PyLuceneDatabase, self).__init__(basedir, analyzer=analyzer,
-                create_allowed=create_allowed)
+        super(PyLuceneDatabase, self).__init__(
+            basedir, analyzer=analyzer, create_allowed=create_allowed)
         self.pyl_analyzer = PyLucene.StandardAnalyzer()
         self.writer = None
         self.reader = None
@@ -107,11 +108,11 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
                     os.makedirs(parent_path)
             except IOError as err_msg:
                 raise OSError("Indexer: failed to create the parent "
-                              "directory (%s) of the indexing database: %s" % (
-                              parent_path, err_msg))
+                              "directory (%s) of the indexing database: %s" %
+                              (parent_path, err_msg))
             try:
-                tempwriter = PyLucene.IndexWriter(self.location,
-                        self.pyl_analyzer, True)
+                tempwriter = PyLucene.IndexWriter(
+                    self.location, self.pyl_analyzer, True)
                 tempwriter.close()
             except PyLucene.JavaError as err_msg:
                 raise OSError("Indexer: failed to open or create a Lucene"
@@ -201,8 +202,7 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
         value = value.replace("-", " ")
         return PyLucene.QueryParser.escape(value)
 
-    def _create_query_for_string(self, text, require_all=True,
-            analyzer=None):
+    def _create_query_for_string(self, text, require_all=True, analyzer=None):
         """generate a query for a plain term of a string query
 
         basically this function parses the string and returns the resulting
@@ -290,7 +290,7 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
         combined_query = PyLucene.BooleanQuery()
         for query in queries:
             combined_query.add(
-                    PyLucene.BooleanClause(query, _occur(require_all, False)))
+                PyLucene.BooleanClause(query, _occur(require_all, False)))
         return combined_query
 
     def _create_empty_document(self):
@@ -315,8 +315,9 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
             token_flag = PyLucene.Field.Index.TOKENIZED
         else:
             token_flag = PyLucene.Field.Index.UN_TOKENIZED
-        document.add(PyLucene.Field(str(UNNAMED_FIELD_NAME), term,
-                PyLucene.Field.Store.YES, token_flag))
+        document.add(PyLucene.Field(
+            str(UNNAMED_FIELD_NAME), term, PyLucene.Field.Store.YES,
+            token_flag))
 
     def _add_field_term(self, document, field, term, tokenize=True):
         """add a field term to a document
@@ -334,8 +335,8 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
             token_flag = PyLucene.Field.Index.TOKENIZED
         else:
             token_flag = PyLucene.Field.Index.UN_TOKENIZED
-        document.add(PyLucene.Field(str(field), term,
-                PyLucene.Field.Store.YES, token_flag))
+        document.add(PyLucene.Field(
+            str(field), term, PyLucene.Field.Store.YES, token_flag))
 
     def _add_document_to_index(self, document):
         """add a prepared document to the index database
@@ -421,7 +422,7 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
         :return: a list of dicts containing the specified field(s)
         :rtype: list of dicts
         """
-        if isinstance(fieldnames, basestring):
+        if isinstance(fieldnames, six.string_types):
             fieldnames = [fieldnames]
         hits = self.searcher.search(query)
         if _COMPILER == 'jcc':
@@ -451,7 +452,7 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
                 if age > 15:
                     logging.warning("stale lock found in %s, removing.", self.location)
                     self.reader.unlock(self.reader.directory())
-            except:
+            except Exception:
                 pass
 
     def _writer_open(self):
@@ -460,8 +461,8 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
         """
         if not self._writer_is_open():
             self._delete_stale_lock()
-            self.writer = PyLucene.IndexWriter(self.location, self.pyl_analyzer,
-                    False)
+            self.writer = PyLucene.IndexWriter(
+                self.location, self.pyl_analyzer, False)
             # "setMaxFieldLength" is available since PyLucene v2
             # we must stay compatible to v1 for the derived class
             # (PyLuceneIndexer1) - thus we make this step optional
@@ -477,7 +478,7 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
 
     def _writer_is_open(self):
         """check if the indexing write access is currently open"""
-        return hasattr(self, "writer") and not self.writer is None
+        return hasattr(self, "writer") and self.writer is not None
 
     def _index_refresh(self):
         """re-read the indexer database"""
@@ -486,7 +487,7 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
                 self.reader = PyLucene.IndexReader.open(self.location)
                 self.searcher = PyLucene.IndexSearcher(self.reader)
             elif (self.index_version !=
-                      self.reader.getCurrentVersion(self.location)):
+                  self.reader.getCurrentVersion(self.location)):
                 self.searcher.close()
                 self.reader.close()
                 self.reader = PyLucene.IndexReader.open(self.location)
