@@ -28,6 +28,7 @@ import six
 from lxml import etree
 
 from translate.lang import data
+from translate.misc.deprecation import deprecated
 from translate.storage import base, lisa
 from translate.misc.multistring import multistring
 
@@ -44,7 +45,7 @@ class AndroidResourceUnit(base.TranslationUnit):
     def createfromxmlElement(cls, element):
         term = None
         # Actually this class supports only plurals and string tags
-        if ((element.tag == "plurals") or (element.tag == "string")):
+        if element.tag == "plurals" or element.tag == "string":
             term = cls(None, xmlelement=element)
         return term
 
@@ -178,7 +179,7 @@ class AndroidResourceUnit(base.TranslationUnit):
                     elif c == ' ':
                         text[i-1:i+1] = ' '  # an actual space
                         i -= 1
-                    elif c in '"\'@':
+                    elif c in '"\'@?':
                         text[i-1:i] = ''  # remove the backslash
                         i -= 1
                     elif c == 'u':
@@ -237,6 +238,7 @@ class AndroidResourceUnit(base.TranslationUnit):
         text = text.replace('\n', '\n\\n')
         text = text.replace('\t', '\\t')
         text = text.replace('\'', '\\\'')
+        text = text.replace('?', '\\?')
         text = text.replace('"', '\\"')
 
         # @ needs to be escaped at start
@@ -248,16 +250,46 @@ class AndroidResourceUnit(base.TranslationUnit):
             return '"%s"' % text
         return text
 
-    def setsource(self, source):
-        super(AndroidResourceUnit, self).setsource(source)
-
-    def getsource(self, lang=None):
-        if (super(AndroidResourceUnit, self).source is None):
+    @base.TranslationUnit.source.getter
+    def source(self):
+        if super(AndroidResourceUnit, self).source is None:
             return self.target
-        else:
-            return super(AndroidResourceUnit, self).source
+        return super(AndroidResourceUnit, self).source
 
-    source = property(getsource, setsource)
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
+
+    def get_xml_text_value(self, xmltarget):
+        if len(xmltarget) == 0:
+            # There are no html markups, so unescaping it as plain text.
+            return self.unescape(xmltarget.text)
+        else:
+            # There are html markups, so clone it to perform unescaping for all elements.
+            cloned_target = copy.deepcopy(xmltarget)
+
+            # Unescaping texts.
+            if cloned_target.text is not None:
+                cloned_target.text = self.unescape(cloned_target.text, False)
+            for xmlelement in cloned_target.iterdescendants():
+                if xmlelement.text is not None:
+                    xmlelement.text = self.unescape(xmlelement.text, False)
+                if xmlelement.tail is not None:
+                    xmlelement.tail = self.unescape(xmlelement.tail, False)
+
+            # Grab root text (using a temporary xml element for text escaping)
+            if cloned_target.text is not None:
+                tmp_element = etree.Element('t')
+                tmp_element.text = cloned_target.text
+                target = data.forceunicode(etree.tostring(tmp_element, encoding='utf-8')[3:-4])
+            else:
+                target = u''
+
+            # Include markup as well
+            target += u''.join([data.forceunicode(etree.tostring(child, encoding='utf-8'))
+                                for child in cloned_target.iterchildren()])
+            return target
 
     def set_xml_text_value(self, target, xmltarget):
         if '<' in target:
@@ -291,8 +323,16 @@ class AndroidResourceUnit(base.TranslationUnit):
             # Handle text only
             xmltarget.text = self.escape(target)
 
-    def settarget(self, target):
-        if (self.hasplurals(self.source) or self.hasplurals(target)):
+    @property
+    def target(self):
+        if self.xmlelement.tag != "plurals":
+            return self.get_xml_text_value(self.xmlelement)
+        return multistring([data.forceunicode(self.get_xml_text_value(entry))
+                            for entry in self.xmlelement.iterchildren()])
+
+    @target.setter
+    def target(self, target):
+        if self.hasplurals(self.source) or self.hasplurals(target):
             # Fix the root tag if mismatching
             if self.xmlelement.tag != "plurals":
                 old_id = self.getid()
@@ -301,10 +341,7 @@ class AndroidResourceUnit(base.TranslationUnit):
                 self.setid(old_id)
 
             locale = self.gettargetlanguage().replace('_', '-').split('-')[0]
-            try:
-                lang_tags = data.plural_tags[locale]
-            except KeyError:
-                lang_tags = data.plural_tags['en']
+            lang_tags = data.plural_tags.get(locale, data.plural_tags['en'])
 
             # Get plural tags in the right order.
             plural_tags = [tag for tag in ['zero', 'one', 'two', 'few', 'many', 'other'] if tag in lang_tags]
@@ -346,48 +383,13 @@ class AndroidResourceUnit(base.TranslationUnit):
 
             self.set_xml_text_value(target, self.xmlelement)
 
-        super(AndroidResourceUnit, self).settarget(target)
+        self._rich_target = None
+        self._target = target
 
-    def get_xml_text_value(self, xmltarget):
-        if (len(xmltarget) == 0):
-            # There are no html markups, so unescaping it as plain text.
-            return self.unescape(xmltarget.text)
-        else:
-            # There are html markups, so clone it to perform unescaping for all elements.
-            cloned_target = copy.deepcopy(xmltarget)
-
-            # Unescaping texts.
-            if (cloned_target.text is not None):
-                cloned_target.text = self.unescape(cloned_target.text, False)
-            for xmlelement in cloned_target.iterdescendants():
-                if (xmlelement.text is not None):
-                    xmlelement.text = self.unescape(xmlelement.text, False)
-                if (xmlelement.tail is not None):
-                    xmlelement.tail = self.unescape(xmlelement.tail, False)
-
-            # Grab root text (using a temporary xml element for text escaping)
-            if (cloned_target.text is not None):
-                tmp_element = etree.Element('t')
-                tmp_element.text = cloned_target.text
-                target = data.forceunicode(etree.tostring(tmp_element, encoding='utf-8')[3:-4])
-            else:
-                target = u''
-
-            # Include markup as well
-            target += u''.join([data.forceunicode(etree.tostring(child, encoding='utf-8'))
-                                for child in cloned_target.iterchildren()])
-            return target
-
-    def gettarget(self, lang=None):
-        if (self.xmlelement.tag == "plurals"):
-            target = []
-            for entry in self.xmlelement.iterchildren():
-                target.append(data.forceunicode(self.get_xml_text_value(entry)))
-            return multistring(target)
-        else:
-            return self.get_xml_text_value(self.xmlelement)
-
-    target = property(gettarget, settarget)
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
+    def gettarget(self):
+        return self.target
 
     def getlanguageNode(self, lang=None, index=None):
         return self.xmlelement
@@ -404,7 +406,7 @@ class AndroidResourceUnit(base.TranslationUnit):
     def getnotes(self, origin=None):
         if origin in ['programmer', 'developer', 'source code', None]:
             comments = []
-            if (self.xmlelement is not None):
+            if self.xmlelement is not None:
                 prevSibling = self.xmlelement.getprevious()
                 while ((prevSibling is not None) and (prevSibling.tag is etree.Comment)):
                     comments.insert(0, prevSibling.text)
@@ -480,13 +482,13 @@ class AndroidResourceFile(lisa.LISAfile):
         target_lang = super(AndroidResourceFile, self).gettargetlanguage()
 
         # If targetlanguage isn't set, we try to extract it from the filename path (if any).
-        if (target_lang is None) and hasattr(self, 'filename') and self.filename:
+        if target_lang is None and hasattr(self, 'filename') and self.filename:
             # Android standards expect resource files to be in a directory named "values[-<lang>[-r<region>]]".
             parent_dir = os.path.split(os.path.dirname(self.filename))[1]
             match = re.search('^values-(\w*)', parent_dir)
-            if (match is not None):
+            if match is not None:
                 target_lang = match.group(1)
-            elif (parent_dir == 'values'):
+            elif parent_dir == 'values':
                 # If the resource file is inside the "values" directory, then it is the default/source language.
                 target_lang = self.sourcelanguage
 
