@@ -245,7 +245,16 @@ class dtdunit(base.TranslationUnit):
         self.closing = ">"
 
     # Note that source and target are equivalent for monolingual units
-    def setsource(self, source):
+    @property
+    def source(self):
+        """gets the unquoted source string"""
+        if self.android:
+            return unquotefromandroid(self.definition)
+        else:
+            return unquotefromdtd(self.definition)
+
+    @source.setter
+    def source(self, source):
         """Sets the definition to the quoted value of source"""
         if self.android:
             self.definition = quoteforandroid(source)
@@ -253,15 +262,21 @@ class dtdunit(base.TranslationUnit):
             self.definition = quotefordtd(source)
         self._rich_source = None
 
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
     def getsource(self):
-        """gets the unquoted source string"""
+        return self.source
+
+    @property
+    def target(self):
+        """gets the unquoted target string"""
         if self.android:
             return unquotefromandroid(self.definition)
         else:
             return unquotefromdtd(self.definition)
-    source = property(getsource, setsource)
 
-    def settarget(self, target):
+    @target.setter
+    def target(self, target):
         """Sets the definition to the quoted value of target"""
         if target is None:
             target = ""
@@ -271,13 +286,10 @@ class dtdunit(base.TranslationUnit):
             self.definition = quotefordtd(target)
         self._rich_target = None
 
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
     def gettarget(self):
-        """gets the unquoted target string"""
-        if self.android:
-            return unquotefromandroid(self.definition)
-        else:
-            return unquotefromdtd(self.definition)
-    target = property(gettarget, settarget)
+        return self.target
 
     def getid(self):
         return self.entity
@@ -569,11 +581,6 @@ class dtdfile(base.TranslationStore):
             warnings.warn("DTD file '%s' does not validate" % self.filename)
             out.truncate(0)
 
-    # Deprecated on 2.0.0
-    @deprecated("Use bytes(dtdfile) instead")
-    def getoutput(self):
-        return bytes(self)
-
     def makeindex(self):
         """makes self.id_index dictionary keyed on entities"""
         self.id_index = {}
