@@ -73,6 +73,7 @@ from collections import OrderedDict
 
 import six
 
+from translate.misc.deprecation import deprecated
 from translate.misc.multistring import multistring
 from translate.storage import base
 
@@ -97,12 +98,18 @@ class JsonUnit(base.TranslationUnit):
                 self.target = str(source)
         super(JsonUnit, self).__init__(source)
 
-    def getsource(self):
+    @property
+    def source(self):
         return self.target
 
-    def setsource(self, source):
+    @source.setter
+    def source(self, source):
         self.target = source
-    source = property(getsource, setsource)
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
 
     def setid(self, value):
         self._id = value
@@ -225,7 +232,7 @@ class JsonNestedUnit(JsonUnit):
     def getvalue(self):
         ret = self.converttarget()
         for k in reversed(self.getkey()):
-            ret = {k: ret}
+            ret = OrderedDict({k: ret})
         return ret
 
 
@@ -268,7 +275,12 @@ class I18NextUnit(JsonNestedUnit):
     See https://www.i18next.com/
     """
 
-    def settarget(self, target):
+    @property
+    def target(self):
+        return self._target
+
+    @target.setter
+    def target(self, target):
         def get_base(item):
             """Return base name for plurals"""
             if '_0' in item[0]:
@@ -291,8 +303,9 @@ class I18NextUnit(JsonNestedUnit):
         elif isinstance(self._item, list):
             # Changing plural to singular
             self._item = get_base(self._item)
-        super(I18NextUnit, self).settarget(target)
-    target = property(lambda self: self._target, settarget)
+
+        self._rich_target = None
+        self._target = target
 
     def getvalue(self):
         if not isinstance(self.target, multistring):
