@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2008, 2014 Zuza Software Foundation
@@ -20,10 +19,6 @@
 
 import zipfile
 
-from lxml import etree
-
-from translate.storage.xml_name import XmlNamer
-
 
 def open_odf(filename):
     z = zipfile.ZipFile(filename, 'r')
