@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2002-2008 Zuza Software Foundation
@@ -34,20 +33,22 @@ comments.
 
 import os
 import re
+import six
 import warnings
+from io import BytesIO
 
 from translate.misc import quote, wStringIO
 
 
 # File normalisation
 
-normalfilenamechars = "/#.0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
-normalizetable = ""
-for i in map(chr, range(256)):
+normalfilenamechars = b"/#.0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
+normalizetable = b""
+for i in map(six.int2byte, range(256)):
     if i in normalfilenamechars:
         normalizetable += i
     else:
-        normalizetable += "_"
+        normalizetable += b"_"
 
 
 class unormalizechar(dict):
@@ -60,12 +61,13 @@ class unormalizechar(dict):
     def __getitem__(self, key):
         return self.normalchars.get(key, u"_")
 
+
 unormalizetable = unormalizechar(normalfilenamechars.decode("ascii"))
 
 
 def normalizefilename(filename):
     """converts any non-alphanumeric (standard roman) characters to _"""
-    if isinstance(filename, str):
+    if isinstance(filename, bytes):
         return filename.translate(normalizetable)
     else:
         return filename.translate(unormalizetable)
@@ -84,7 +86,7 @@ def makekey(ookey, long_keys):
     project, sourcefile, resourcetype, groupid, localid, platform = ookey
     sourcefile = sourcefile.replace('\\', '/')
     if long_keys:
-        sourcebase = os.path.join(project, sourcefile)
+        sourcebase = '/'.join((project, sourcefile))
     else:
         sourceparts = sourcefile.split('/')
         sourcebase = "".join(sourceparts[-1:])
@@ -125,8 +127,9 @@ def escape_text(text):
 
 def unescape_text(text):
     """Unescapes SDF text to be suitable for unit consumption."""
-    return text.replace("\\\\", "\a").replace("\\n", "\n").replace("\\t", "\t").\
-           replace("\\r", "\r").replace("\a", "\\\\")
+    return text.replace("\\\\", "\a").replace("\\n", "\n").replace("\\t", "\t") \
+        .replace("\\r", "\r").replace("\a", "\\\\")
+
 
 helptagre = re.compile('''<[/]??[a-z_\-]+?(?:| +[a-z]+?=".*?") *[/]??>''')
 
@@ -159,13 +162,6 @@ def unescape_help_text(text):
     return text.replace(r"\<", "<").replace(r"\>", ">").replace(r'\"', '"').replace(r"\\", "\\")
 
 
-def encode_if_needed_utf8(text):
-    """Encode a Unicode string the the specified encoding"""
-    if isinstance(text, unicode):
-        return text.encode('UTF-8')
-    return text
-
-
 class ooline(object):
     """this represents one line, one translation in an .oo file"""
 
@@ -218,8 +214,8 @@ class ooline(object):
     text = property(gettext, settext)
 
     def __str__(self):
-        """convert to a string. double check that unicode is handled"""
-        return encode_if_needed_utf8(self.getoutput())
+        """convert to a string."""
+        return self.getoutput()
 
     def getoutput(self):
         """return a line in tab-delimited form"""
@@ -232,6 +228,7 @@ class ooline(object):
                 self.localid, self.platform)
 
 
+@six.python_2_unicode_compatible
 class oounit:
     """this represents a number of translations of a resource"""
 
@@ -246,8 +243,8 @@ class oounit:
         self.lines.append(line)
 
     def __str__(self):
-        """convert to a string. double check that unicode is handled"""
-        return encode_if_needed_utf8(self.getoutput())
+        """convert to a string."""
+        return self.getoutput()
 
     def getoutput(self, skip_source=False, fallback_lang=None):
         """return the lines in tab-delimited form"""
@@ -260,12 +257,14 @@ class oounit:
                 lines = [new_line]
         else:
             lines = self.lines
-        return "\r\n".join([str(line) for line in lines])
+        return "\r\n".join([six.text_type(line) for line in lines])
 
 
 class oofile:
     """this represents an entire .oo file"""
+
     UnitClass = oounit
+    encoding = 'utf-8'
 
     def __init__(self, input=None):
         """constructs the oofile"""
@@ -299,6 +298,7 @@ class oofile:
             input.close()
         else:
             src = input
+        src = src.decode(self.encoding)
         for line in src.split("\n"):
             line = quote.rstripeol(line)
             if not line:
@@ -307,9 +307,21 @@ class oofile:
             thisline = ooline(parts)
             self.addline(thisline)
 
-    def __str__(self, skip_source=False, fallback_lang=None):
+    def __str__(self, *args, **kwargs):
+        if six.PY2:
+            out = BytesIO()
+            self.serialize(out, **kwargs)
+            return out.getvalue()
+        return super(oofile, self).__str__()
+
+    def __bytes__(self):
+        out = BytesIO()
+        self.serialize(out)
+        return out.getvalue()
+
+    def serialize(self, out, skip_source=False, fallback_lang=None):
         """convert to a string. double check that unicode is handled"""
-        return encode_if_needed_utf8(self.getoutput(skip_source, fallback_lang))
+        out.write(self.getoutput(skip_source, fallback_lang).encode(self.encoding))
 
     def getoutput(self, skip_source=False, fallback_lang=None):
         """converts all the lines back to tab-delimited form"""
@@ -325,7 +337,11 @@ class oofile:
 
 
 class oomultifile:
-    """this takes a huge GSI file and represents it as multiple smaller files..."""
+    """this takes a huge GSI file and represents it as multiple smaller
+    files...
+    """
+
+    encoding = 'utf-8'
 
     def __init__(self, filename, mode=None, multifilestyle="single"):
         """initialises oomultifile from a seekable inputfile or writable outputfile"""
@@ -340,7 +356,7 @@ class oomultifile:
         self.multifilename = os.path.splitext(filename)[0]
         self.multifile = open(filename, mode)
         self.subfilelines = {}
-        if mode == "r":
+        if mode.startswith("r"):
             self.createsubfileindex()
 
     def createsubfileindex(self):
@@ -348,7 +364,7 @@ class oomultifile:
         linenum = 0
         for line in self.multifile:
             subfile = self.getsubfilename(line)
-            if not subfile in self.subfilelines:
+            if subfile not in self.subfilelines:
                 self.subfilelines[subfile] = []
             self.subfilelines[subfile].append(linenum)
             linenum += 1
@@ -405,6 +421,8 @@ class oomultifile:
         """returns a pseudo-file object for the given subfile"""
 
         def onclose(contents):
+            if isinstance(contents, bytes):
+                contents = contents.decode(self.encoding)
             self.multifile.write(contents)
             self.multifile.flush()
         outputfile = wStringIO.CatchStringOutput(onclose)
