@@ -66,6 +66,7 @@ from phply.phpast import (Array, ArrayElement, ArrayOffset, Assignment,
                           BinaryOp, FunctionCall, InlineHTML, Node, Return,
                           Variable)
 
+from translate.misc.deprecation import deprecated
 from translate.storage import base
 
 
@@ -146,6 +147,14 @@ class PHPLexer(FilteredLexer):
             return '"'
         return '\''
 
+    def extract_array(self):
+        pos = max(self.pos, self.codepos)
+        while self.tokens[pos].type not in ('ARRAY', 'LBRACKET'):
+            pos += 1
+        if self.tokens[pos].type == 'ARRAY':
+            return ''
+        return '[]'
+
 
 def phpencode(text, quotechar="'"):
     """Convert Python string to PHP escaping.
@@ -223,22 +232,34 @@ class phpunit(base.TranslationUnit):
         self._comments = []
         self.source = source
 
-    def setsource(self, source):
+    @property
+    def source(self):
+        return phpdecode(self.value, self.escape_type)
+
+    @source.setter
+    def source(self, source):
         """Set the source AND the target to be equal."""
         self._rich_source = None
         self.value = phpencode(source, self.escape_type)
 
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
     def getsource(self):
-        return phpdecode(self.value, self.escape_type)
-    source = property(getsource, setsource)
+        return self.source
 
-    def settarget(self, target):
+    @property
+    def target(self):
+        return phpdecode(self.translation, self.escape_type)
+
+    @target.setter
+    def target(self, target):
         self._rich_target = None
         self.translation = phpencode(target, self.escape_type)
 
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
     def gettarget(self):
-        return phpdecode(self.translation, self.escape_type)
-    target = property(gettarget, settarget)
+        return self.target
 
     def __str__(self):
         """Convert to a string."""
@@ -319,11 +340,25 @@ class phpfile(base.TranslationStore):
             if arrname in handled:
                 return
             childs = set()
-            write('{}{} {} array(\n'.format(
-                ' ' * indent,
-                arrname.rsplit('->', 1)[-1],
-                '=>' if '->' in arrname else '='
-            ))
+            # Default to classic array
+            init = 'array('
+            close = ')'
+            name = arrname
+            # Handle [] style array
+            if name.endswith('[]'):
+                init = '['
+                close = ']'
+                name = name[:-2]
+            # Handle return, assignment or sub array
+            if '->' in arrname:
+                separator = ' =>'
+                name = name.rsplit('->', 1)[-1]
+            elif name == 'return':
+                separator = ''
+            else:
+                separator = ' ='
+            # Write array start
+            write('{}{}{} {}\n'.format(' ' * indent, name, separator, init))
             indent += 4
             prefix = '{}->'.format(arrname)
             pref_len = len(prefix)
@@ -335,8 +370,10 @@ class phpfile(base.TranslationStore):
                     handle_array(item, prefix + name.split('->', 1)[0], childs, indent)
                 else:
                     write(item.getoutput(' ' * indent, name))
-            write('{}){}\n'.format(
+            # Write array end
+            write('{}{}{}\n'.format(
                 ' ' * (indent - 4),
+                close,
                 ',' if '->' in arrname else ';'
             ))
             handled.add(arrname)
@@ -363,6 +400,7 @@ class phpfile(base.TranslationStore):
     def parse(self, phpsrc):
         """Read the source of a PHP file in and include them as units."""
         def handle_array(prefix, nodes, lexer):
+            prefix += lexer.extract_array()
             for item in nodes:
                 assert isinstance(item, ArrayElement)
                 # Skip empty keys
@@ -413,37 +451,39 @@ class phpfile(base.TranslationStore):
                     )
             elif isinstance(item, Assignment):
                 if isinstance(item.node, ArrayOffset):
+                    name = lexer.extract_name('EQUALS', *item.lexpositions)
                     if isinstance(item.expr, six.string_types):
                         self.create_and_add_unit(
-                            lexer.extract_name('EQUALS', *item.lexpositions),
+                            name,
                             item.expr,
                             lexer.extract_quote(),
                             lexer.extract_comments(item.lexpositions[1]),
                         )
                     elif isinstance(item.expr, BinaryOp) and item.expr.op == '.':
                         self.create_and_add_unit(
-                            lexer.extract_name('EQUALS', *item.lexpositions),
+                            name,
                             concatenate(item.expr),
                             lexer.extract_quote(),
                             lexer.extract_comments(item.lexpositions[1]),
                         )
                 elif isinstance(item.node, Variable):
+                    name = lexer.extract_name('EQUALS', *item.lexpositions)
                     if isinstance(item.expr, Array):
-                        handle_array(item.node.name, item.expr.nodes, lexer)
+                        handle_array(name, item.expr.nodes, lexer)
                     elif isinstance(item.expr, six.string_types):
                         self.create_and_add_unit(
-                            item.node.name,
+                            name,
                             item.expr,
                             lexer.extract_quote(),
                             lexer.extract_comments(item.lexpositions[1]),
                         )
                     elif isinstance(item.expr, BinaryOp) and item.expr.op == '.':
                         self.create_and_add_unit(
-                            item.node.name,
+                            name,
                             concatenate(item.expr),
                             lexer.extract_quote(),
                             lexer.extract_comments(item.lexpositions[1]),
                         )
             elif isinstance(item, Return):
                 if isinstance(item.node, Array):
-                    handle_array('', item.node.nodes, lexer)
+                    handle_array('return', item.node.nodes, lexer)
