@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2004-2006,2008-2009 Zuza Software Foundation
@@ -28,7 +27,9 @@
 """
 
 import re
+import six
 
+from translate.misc.deprecation import deprecated
 from translate.storage import base
 
 
@@ -50,10 +51,11 @@ def escape_to_rc(string):
     return rcstring
 
 
+@six.python_2_unicode_compatible
 class rcunit(base.TranslationUnit):
     """A unit of an rc file"""
 
-    def __init__(self, source="", encoding="cp1252"):
+    def __init__(self, source="", **kwargs):
         """Construct a blank rcunit."""
         super(rcunit, self).__init__(source)
         self.name = ""
@@ -61,33 +63,40 @@ class rcunit(base.TranslationUnit):
         self.comments = []
         self.source = source
         self.match = None
-        self.encoding = encoding
 
-    def setsource(self, source):
+    @property
+    def source(self):
+        return self._value
+
+    @source.setter
+    def source(self, source):
         """Sets the source AND the target to be equal"""
         self._rich_source = None
         self._value = source or ""
 
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
     def getsource(self):
-        return self._value
+        return self.source
 
-    source = property(getsource, setsource)
+    @property
+    def target(self):
+        return self.source
 
-    def settarget(self, target):
+    @target.setter
+    def target(self, target):
         """.. note:: This also sets the ``.source`` attribute!"""
         self._rich_target = None
         self.source = target
 
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
     def gettarget(self):
-        return self.source
-    target = property(gettarget, settarget)
+        return self.target
 
     def __str__(self):
-        """Convert to a string. Double check that unicode is handled somehow here."""
-        source = self.getoutput()
-        if isinstance(source, unicode):
-            return source.encode(getattr(self, "encoding", "UTF-8"))
-        return source
+        """Convert to a string."""
+        return self.getoutput()
 
     def getoutput(self):
         """Convert the element back into formatted lines for a .rc file."""
@@ -115,18 +124,20 @@ class rcunit(base.TranslationUnit):
 
 class rcfile(base.TranslationStore):
     """This class represents a .rc file, made up of rcunits."""
-    UnitClass = rcunit
 
-    def __init__(self, inputfile=None, lang=None, sublang=None, encoding="cp1252"):
+    UnitClass = rcunit
+    default_encoding = "cp1252"
+
+    def __init__(self, inputfile=None, lang=None, sublang=None, **kwargs):
         """Construct an rcfile, optionally reading in from inputfile."""
-        self.encoding = encoding
-        super(rcfile, self).__init__(unitclass=self.UnitClass)
+        super(rcfile, self).__init__(**kwargs)
         self.filename = getattr(inputfile, 'name', '')
         self.lang = lang
         self.sublang = sublang
         if inputfile is not None:
-            rcsrc = inputfile.read().decode(encoding)
+            rcsrc = inputfile.read().decode(self.encoding)
             inputfile.close()
+            rcsrc = rcsrc.replace('\r', '')
             self.parse(rcsrc)
 
     def parse(self, rcsrc):
@@ -235,6 +246,6 @@ class rcfile(base.TranslationStore):
                     newunit.match = match
                     self.addunit(newunit)
 
-    def __str__(self):
-        """Convert the units back to lines."""
-        return "".join(self.blocks)
+    def serialize(self, out):
+        """Write the units back to file."""
+        out.write(("".join(self.blocks)).encode(self.encoding))
