@@ -23,6 +23,7 @@
 from lxml import etree
 
 from translate.lang import data
+from translate.misc.deprecation import deprecated
 from translate.misc.xml_helpers import setXMLspace
 from translate.storage import base, lisa
 from translate.storage.placeables import general
@@ -43,38 +44,54 @@ class RESXUnit(lisa.LISAunit):
         langset = etree.Element(self.namespaced(self.languageNode))
 
         langset.text = text
+        # assume no <comment>, closing </data> indents with 2 spaces
+        langset.tail = u"\n  "
         return langset
 
     def _gettargetnode(self):
         return self.xmlelement.find(self.namespaced(self.languageNode))
 
-    def getsource(self):
+    @lisa.LISAunit.source.getter
+    def source(self):
         return self.target
 
-    def settarget(self, text, lang='xx', append=False):
-        # Firstly deal with reinitialising to None or setting to identical
-        # string.
-        self._rich_target = None
-        if self.target == text:
-            return
-        strings = []
-        if isinstance(text, list):
-            strings = text
-        else:
-            strings = [text]
-        targetnode = self._gettargetnode()
-        targetnode.clear()
-        targetnode.text = data.forceunicode(text) or u""
-        targetnode.tail = u"\n    "
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
 
-    def gettarget(self, lang=None):
+    @property
+    def target(self):
         targetnode = self._gettargetnode()
         if targetnode is None:
             etree.SubElement(self.xmlelement, self.namespaced("value"))
             return None
         return data.forceunicode(targetnode.text) or u""
-    target = property(gettarget, settarget)
-    rich_target = property(base.TranslationUnit._get_rich_target, base.TranslationUnit._set_rich_target)
+
+    @target.setter
+    def target(self, target):
+        # Firstly deal with reinitialising to None or setting to identical
+        # string.
+        self._rich_target = None
+        if self.target == target:
+            return
+        targetnode = self._gettargetnode()
+        targetnode.clear()
+        targetnode.text = data.forceunicode(target) or u""
+        # Assume no <comment> follows; allow the </data> element
+        # to be indented with 2 spaces (same level as the opening
+        # <data> element before <value>)
+        targetnode.tail = u"\n  "
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
+    def gettarget(self):
+        return self.target
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
+    def settarget(self, target):
+        self.target = target
 
     def addnote(self, text, origin=None, position="append"):
         """Add a note specifically in the appropriate "comment" tag"""
@@ -92,6 +109,14 @@ class RESXUnit(lisa.LISAunit):
                 note.text = "\n".join(filter(None, [current_notes, text_stripped]))
         else:
             note.text = text_stripped
+        if note.text:
+            # Correct the indent of <comment> by updating the tail of
+            # the preceding <value> element
+            targetnode = self._gettargetnode()
+            targetnode.tail = u"\n    "
+        # This also requires putting a matching tail on the <comment>,
+        # otherwise the </data> would yet again be misaligned
+        note.tail = u"\n  "
 
     def getnotes(self, origin=None):
         comments = []
@@ -187,6 +212,12 @@ class RESXFile(lisa.LISAfile):
   <resheader name="version">
     <value>2.0</value>
   </resheader>
+  <resheader name="reader">
+    <value>System.Resources.ResXResourceReader, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089</value>
+  </resheader>
+  <resheader name="writer">
+    <value>System.Resources.ResXResourceWriter, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089</value>
+  </resheader>
 </root>
 '''
     namespace = ''
@@ -208,4 +239,20 @@ class RESXFile(lisa.LISAfile):
         if unit.getid() is None:
             self._messagenum += 1
             unit.setid(u"%s" % unit.source.strip(' '))
+        # adjust the current and previous elements for new ones;
+        # otherwise they will not be indented correctly.
+        if new:
+            previous_node = unit.xmlelement.getprevious()
+            if previous_node is None:
+                # this is the first element; adjust root.
+                # should not happen in a ResX file prepared by Visual Studio
+                # since it includes an inline XSD plus resheader at all times.
+                self.body.text = u"\n  "
+            else:
+                # adjust the <data> tag being added by updating the previous one.
+                previous_node.tail = u"\n  "
+            # adjust the indent of the following <value> element
+            unit.xmlelement.text = u"\n    "
+            # adjust the indent of the closing </root> tag
+            unit.xmlelement.tail = u"\n"
         return unit
