@@ -28,8 +28,8 @@ A patch to gaupol is required to open utf-8 files successfully.
 
 import os
 import six
-import tempfile
 from io import StringIO
+from tempfile import NamedTemporaryFile
 
 try:
     from aeidon import Subtitle, documents, newlines
@@ -38,14 +38,20 @@ try:
                               SubStationAlpha, new)
     from aeidon.util import detect_format as determine
 except ImportError:
-    from gaupol import FormatDeterminer, documents
-    from gaupol.encodings import detect
-    from gaupol.files import (AdvSubStationAlpha, MicroDVD, SubRip,
-                              SubStationAlpha, new)
-    from gaupol.newlines import newlines
-    from gaupol.subtitle import Subtitle
-    _determiner = FormatDeterminer()
-    determine = _determiner.determine
+    try:
+        from gaupol import FormatDeterminer, documents
+        from gaupol.encodings import detect
+        from gaupol.files import (AdvSubStationAlpha, MicroDVD, SubRip,
+                                  SubStationAlpha, new)
+        from gaupol.newlines import newlines
+        from gaupol.subtitle import Subtitle
+        _determiner = FormatDeterminer()
+        determine = _determiner.determine
+    except ImportError:
+        if six.PY3:
+            raise ImportError('\naeidon or gaupol package required for Subtitle support')
+        else:
+            raise ImportError('\ngaupol package required for Subtitle support')
 
 from translate.storage import base
 
@@ -138,14 +144,21 @@ class SubtitleFile(base.TranslationStore):
     def parse(self, input):
         if isinstance(input, bytes):
             # Gaupol does not allow parsing from strings
+            kwargs = {
+                'delete': False
+            }
             if self.filename:
-                tmpfile, tmpfilename = tempfile.mkstemp(suffix=self.filename)
-            else:
-                tmpfile, tmpfilename = tempfile.mkstemp()
-            with open(tmpfilename, 'wb') as fh:
-                fh.write(input)
-            self._parsefile(tmpfilename)
-            os.remove(tmpfilename)
+                kwargs['suffix'] = self.filename
+
+            temp_file = NamedTemporaryFile(**kwargs)
+            temp_file.close()
+
+            try:
+                with open(temp_file.name, 'wb') as fh:
+                    fh.write(input)
+                self._parsefile(temp_file.name)
+            finally:
+                os.unlink(temp_file.name)
         else:
             self._parsefile(input)
 
