@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2013 Zuza Software Foundation
@@ -18,9 +17,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
+from io import BytesIO
 from pytest import mark
 
-from translate.misc import wStringIO
+
 from translate.storage import dtd, test_monolingual
 
 
@@ -191,13 +191,15 @@ class TestDTD(test_monolingual.TestMonolingualStore):
 
     def dtdparse(self, dtdsource):
         """helper that parses dtd source without requiring files"""
-        dummyfile = wStringIO.StringIO(dtdsource)
+        if not isinstance(dtdsource, bytes):
+            dtdsource = dtdsource.encode('utf-8')
+        dummyfile = BytesIO(dtdsource)
         dtdfile = dtd.dtdfile(dummyfile)
         return dtdfile
 
     def dtdregen(self, dtdsource):
         """helper that converts dtd source to dtdfile object and back"""
-        return str(self.dtdparse(dtdsource))
+        return bytes(self.dtdparse(dtdsource)).decode('utf-8')
 
     def test_simpleentity(self):
         """checks that a simple dtd entity definition is parsed correctly"""
@@ -260,6 +262,35 @@ class TestDTD(test_monolingual.TestMonolingualStore):
         print(dtdsource)
         assert dtdsource == dtdregen
 
+        dtdsource = """<!ENTITY malformedURI.longDesc "
+<ul>
+  <li>Web addresses are usually written like
+    <strong>http://www.example.com/</strong></li>
+  <li>Make sure that youre using forward slashes (i.e.
+    <strong>/</strong>).</li>
+</ul>
+">
+"""
+        dtdregen = self.dtdregen(dtdsource)
+        assert dtdsource == dtdregen
+
+        dtdsource = """<!ENTITY certerror.whatShouldIDo.badStsCertExplanation "This site uses HTTP
+Strict Transport Security (HSTS) to specify that &brandShortName; only connect
+to it securely. As a result, it is not possible to add an exception for this
+certificate.">
+"""
+        dtdregen = self.dtdregen(dtdsource)
+        print(dtdregen)
+        print(dtdsource)
+        assert dtdsource == dtdregen
+
+        dtdsource = """<!ENTITY pref.categories.overwrite "A category already exists with that name. \\n Do you want to overwrite it?">
+"""
+        dtdregen = self.dtdregen(dtdsource)
+        print(dtdregen)
+        print(dtdsource)
+        assert dtdsource == dtdregen
+
     def test_conflate_comments(self):
         """Tests that comments don't run onto the same line"""
         dtdsource = '<!-- test comments -->\n<!-- getting conflated -->\n<!ENTITY sample.txt "hello">\n'
@@ -326,7 +357,7 @@ class TestDTD(test_monolingual.TestMonolingualStore):
         assert len(dtdfile.units) == 1
         dtdunit = dtdfile.units[0]
         assert dtdunit.definition == '"bananas for sale"'
-        assert str(dtdfile) == '<!ENTITY test.me "bananas for sale">\n'
+        assert bytes(dtdfile) == b'<!ENTITY test.me "bananas for sale">\n'
 
     def test_missing_quotes(self, recwarn):
         """test that we fail graacefully when a message without quotes is found (bug #161)"""
@@ -397,7 +428,9 @@ class TestAndroidDTD(test_monolingual.TestMonolingualStore):
         This allows to simulate reading from Android DTD files without really
         having real Android DTD files.
         """
-        dummyfile = wStringIO.StringIO(dtdsource)
+        if not isinstance(dtdsource, bytes):
+            dtdsource = dtdsource.encode('utf-8')
+        dummyfile = BytesIO(dtdsource)
         dtdfile = dtd.dtdfile(dummyfile, android=True)
         return dtdfile
 
@@ -408,7 +441,7 @@ class TestAndroidDTD(test_monolingual.TestMonolingualStore):
         in-memory store and writing back to an Android DTD file without really
         having a real file.
         """
-        return str(self.dtdparse(dtdsource))
+        return bytes(self.dtdparse(dtdsource)).decode('utf-8')
 
     # Test for bug #2480
     def test_android_single_quote_escape(self):
