@@ -27,7 +27,7 @@ def test_find_delimiter_pos_multiple():
 def test_find_delimiter_pos_none():
     """Find delimiters when there isn't one"""
     assert properties.DialectJava.find_delimiter(u"key") == (None, -1)
-    assert properties.DialectJava.find_delimiter(u"key\=\:\ ") == (None, -1)
+    assert properties.DialectJava.find_delimiter(u"key\\=\\:\\ ") == (None, -1)
 
 
 def test_find_delimiter_pos_whitespace():
@@ -42,10 +42,10 @@ def test_find_delimiter_pos_whitespace():
 
 def test_find_delimiter_pos_escapes():
     """Find delimiters when potential earlier delimiters are escaped"""
-    assert properties.DialectJava.find_delimiter(u"key\:=value") == ('=', 5)
-    assert properties.DialectJava.find_delimiter(u"key\=: value") == (':', 5)
-    assert properties.DialectJava.find_delimiter(u"key\   value") == (' ', 5)
-    assert properties.DialectJava.find_delimiter(u"key\ key\ key\: = value") == ('=', 16)
+    assert properties.DialectJava.find_delimiter(u"key\\:=value") == ('=', 5)
+    assert properties.DialectJava.find_delimiter(u"key\\=: value") == (':', 5)
+    assert properties.DialectJava.find_delimiter(u"key\\   value") == (' ', 5)
+    assert properties.DialectJava.find_delimiter(u"key\\ key\\ key\\: = value") == ('=', 16)
 
 
 def test_is_line_continuation():
@@ -60,9 +60,9 @@ def test_is_line_continuation():
 def test_key_strip():
     assert properties._key_strip(u"key") == "key"
     assert properties._key_strip(u" key") == "key"
-    assert properties._key_strip(u"\ key") == "\ key"
+    assert properties._key_strip(u"\\ key") == "\\ key"
     assert properties._key_strip(u"key ") == "key"
-    assert properties._key_strip(u"key\ ") == "key\ "
+    assert properties._key_strip(u"key\\ ") == "key\\ "
 
 
 def test_is_comment_one_line():
@@ -159,8 +159,8 @@ class TestProp(test_monolingual.TestMonolingualStore):
         whitespaces = (
             ('key = value', 'key', 'value'),      # Standard for baseline
             (' key =  value', 'key', 'value'),    # Extra \s before key and value
-            ('\ key\ = value', '\ key\ ', 'value'),  # extra space at start and end of key
-            ('key = \ value ', 'key', ' value '),  # extra space at start end end of value
+            ('\\ key\\ = value', '\\ key\\ ', 'value'),  # extra space at start and end of key
+            ('key = \\ value ', 'key', ' value '),  # extra space at start end end of value
         )
         for propsource, key, value in whitespaces:
             propfile = self.propparse(propsource)
@@ -221,12 +221,12 @@ key=value
 
     def test_fullspec_escaped_key(self):
         """Escaped delimeters can be in the key"""
-        prop_source = u"\:\="
+        prop_source = u"\\:\\="
         prop_store = self.propparse(prop_source)
         assert len(prop_store.units) == 1
         unit = prop_store.units[0]
         print(unit)
-        assert unit.name == u"\:\="
+        assert unit.name == u"\\:\\="
 
     def test_fullspec_line_continuation(self):
         """Whitespace delimiter and pre whitespace in line continuation are dropped"""
@@ -262,6 +262,16 @@ key=value
         assert propunit.name == u'I am a "key"'
         assert propunit.source == u'I am a "value"'
 
+    def test_mac_multiline_strings(self):
+        """test can read multiline items used in Mac OS X strings files"""
+        propsource = (r'''"I am a \"key\"" = "I am a \"value\" ''' +
+                      '\n nextline";').encode('utf-16')
+        propfile = self.propparse(propsource, personality="strings")
+        assert len(propfile.units) == 1
+        propunit = propfile.units[0]
+        assert propunit.name == u'I am a "key"'
+        assert propunit.source == u"I am a \"value\" nextline"
+
     def test_mac_strings_unicode(self):
         """Ensure we can handle Unicode"""
         propsource = u'''"I am a “key”" = "I am a “value”";'''.encode('utf-16')
@@ -307,7 +317,7 @@ key=value
         propsource = (u'/* Foo\n'
                       u'Bar\n'
                       u'Baz */\n'
-                      u'"key" = "value"').encode('utf-16')
+                      u'"key" = "value";').encode('utf-16')
         propfile = self.propparse(propsource, personality="strings")
         assert len(propfile.units) == 1
         propunit = propfile.units[0]
@@ -398,6 +408,19 @@ key=value
         assert bom not in result[3:]
         assert b'None' not in result[3:]
 
+    def test_joomla_set_target(self):
+        """test various items used in Joomla files"""
+        propsource = '''COM_EXAMPLE_FOO="This is a test"\n'''.encode('utf-8')
+        proptarget = '''COM_EXAMPLE_FOO="This is another test"\n'''.encode('utf-8')
+        propfile = self.propparse(propsource, personality="joomla")
+        assert len(propfile.units) == 1
+        propunit = propfile.units[0]
+        assert propunit.name == u'COM_EXAMPLE_FOO'
+        assert propunit.source == u'This is a test'
+        assert bytes(propfile) == propsource
+        propunit.target = 'This is another test'
+        assert bytes(propfile) == proptarget
+
     def test_joomla(self):
         """test various items used in Joomla files"""
         propsource = '''; comment\nVALUE="I am a "_QQ_"value"_QQ_""\n'''.encode('utf-8')
