@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2010 Zuza Software Foundation
@@ -18,7 +17,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Manage the Trados .txt Translation Memory format
+u"""Manage the Trados .txt Translation Memory format
 
 A Trados file looks like this:
 
@@ -42,6 +41,7 @@ A Trados file looks like this:
 """
 
 import re
+import six
 import time
 
 try:
@@ -50,6 +50,7 @@ try:
 except ImportError:
     raise ImportError("BeautifulSoup 4 is not installed. Support for Trados txt is disabled.")
 
+from translate.misc.deprecation import deprecated
 from translate.storage import base
 
 
@@ -83,14 +84,14 @@ http://msdn.microsoft.com/en-us/library/aa140283(v=office.10).aspx
 
 def unescape(text):
     """Convert Trados text to normal Unicode string"""
-    for trados_escape, char in RTF_ESCAPES.iteritems():
+    for trados_escape, char in six.iteritems(RTF_ESCAPES):
         text = text.replace(trados_escape, char)
     return text
 
 
 def escape(text):
     """Convert Unicode string to Trodas escapes"""
-    for trados_escape, char in RTF_ESCAPES.iteritems():
+    for trados_escape, char in six.iteritems(RTF_ESCAPES):
         text = text.replace(char, trados_escape)
     return text
 
@@ -101,7 +102,7 @@ class TradosTxtDate(object):
     def __init__(self, newtime=None):
         self._time = None
         if newtime:
-            if isinstance(newtime, basestring):
+            if isinstance(newtime, six.string_types):
                 self.timestring = newtime
             elif isinstance(newtime, time.struct_time):
                 self.time = newtime
@@ -151,9 +152,18 @@ class TradosUnit(base.TranslationUnit):
         self._soup = None
         super(TradosUnit, self).__init__(source)
 
-    def getsource(self):
+    @property
+    def source(self):
         return unescape(self._soup.findAll('seg')[0].contents[0])
-    source = property(getsource, None)
+
+    @source.setter
+    def source(self, source):
+        pass
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
 
     def gettarget(self):
         return unescape(self._soup.findAll('seg')[1].contents[0])
@@ -170,16 +180,17 @@ class TradosSoup(BeautifulSoup):
 
 class TradosTxtTmFile(base.TranslationStore):
     """A Trados translation memory file"""
+
     Name = "Trados Translation Memory"
     Mimetypes = ["application/x-trados-tm"]
     Extensions = ["txt"]
+    UnitClass = TradosUnit
+    default_encoding = 'iso-8859-1'
 
-    def __init__(self, inputfile=None, unitclass=TradosUnit):
+    def __init__(self, inputfile=None, **kwargs):
         """construct a Wordfast TM, optionally reading in from inputfile."""
-        self.UnitClass = unitclass
-        base.TranslationStore.__init__(self, unitclass=unitclass)
+        super(TradosTxtTmFile, self).__init__(**kwargs)
         self.filename = ''
-        self._encoding = 'iso-8859-1'
         if inputfile is not None:
             self.parse(inputfile)
 
@@ -198,6 +209,6 @@ class TradosTxtTmFile(base.TranslationStore):
             unit._soup = TradosSoup(str(tu))
             self.addunit(unit)
 
-    def __str__(self):
+    def serialize(self, out):
         # FIXME turn the lowercased tags back into mixed case
-        return self._soup.prettify()
+        out.write(self._soup.prettify())
