@@ -36,6 +36,7 @@ import six
 from lxml import etree
 
 from translate.lang import data
+from translate.misc.deprecation import deprecated
 from translate.misc.multistring import multistring
 from translate.storage import base, lisa
 from translate.storage.placeables import general
@@ -117,19 +118,36 @@ class tsunit(lisa.LISAunit):
 
     def getlanguageNodes(self):
         """We override this to get source and target nodes."""
-        return [n for n in [self._getsourcenode(), self._gettargetnode()] if n is not None]
+        return [n for n in [self._getsourcenode(), self._gettargetnode()]
+                if n is not None]
 
-    def getsource(self):
+    @lisa.LISAunit.source.getter
+    def source(self):
         # TODO: support <byte>. See bug 528.
-        sourcenode = self._getsourcenode()
+        text = data.forceunicode(self._getsourcenode().text)
         if self.hasplural():
-            return multistring([sourcenode.text])
-        else:
-            return data.forceunicode(sourcenode.text)
-    source = property(getsource, lisa.LISAunit.setsource)
-    rich_source = property(base.TranslationUnit._get_rich_source, base.TranslationUnit._set_rich_source)
+            return multistring([text])
+        return text
 
-    def settarget(self, text):
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
+
+    @property
+    def target(self):
+        targetnode = self._gettargetnode()
+        if targetnode is None:
+            etree.SubElement(self.xmlelement, self.namespaced("translation"))
+            return None
+        if self.hasplural():
+            numerus_nodes = targetnode.findall(self.namespaced("numerusform"))
+            return multistring([data.forceunicode(node.text) or u"" for node in numerus_nodes])
+        else:
+            return data.forceunicode(targetnode.text) or u""
+
+    @target.setter
+    def target(self, target):
         # This is a fairly destructive implementation. Don't assume that this
         # is necessarily correct in all regards, but it does deal with a lot of
         # cases. It is hard to deal with plurals.
@@ -137,15 +155,15 @@ class tsunit(lisa.LISAunit):
         # Firstly deal with reinitialising to None or setting to identical
         # string.
         self._rich_target = None
-        if self.target == text:
+        if self.target == target:
             return
         strings = []
-        if isinstance(text, multistring):
-            strings = text.strings
-        elif isinstance(text, list):
-            strings = text
+        if isinstance(target, multistring):
+            strings = target.strings
+        elif isinstance(target, list):
+            strings = target
         else:
-            strings = [text]
+            strings = [target]
         targetnode = self._gettargetnode()
         type = targetnode.get("type")
         targetnode.clear()
@@ -159,21 +177,13 @@ class tsunit(lisa.LISAunit):
                 # manual, nasty pretty printing. See bug 1420.
                 numerus.tail = u"\n        "
         else:
-            targetnode.text = data.forceunicode(text) or u""
+            targetnode.text = data.forceunicode(target) or u""
             targetnode.tail = u"\n    "
 
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
     def gettarget(self):
-        targetnode = self._gettargetnode()
-        if targetnode is None:
-            etree.SubElement(self.xmlelement, self.namespaced("translation"))
-            return None
-        if self.hasplural():
-            numerus_nodes = targetnode.findall(self.namespaced("numerusform"))
-            return multistring([node.text or u"" for node in numerus_nodes])
-        else:
-            return data.forceunicode(targetnode.text) or u""
-    target = property(gettarget, settarget)
-    rich_target = property(base.TranslationUnit._get_rich_target, base.TranslationUnit._set_rich_target)
+        return self.target
 
     def hasplural(self):
         return self.xmlelement.get("numerus") == "yes"
@@ -189,7 +199,9 @@ class tsunit(lisa.LISAunit):
         else:
             note = etree.SubElement(self.xmlelement, self.namespaced("translatorcomment"))
         if position == "append":
-            note.text = "\n".join(filter(None, [current_notes, text.strip()]))
+            note.text = "\n".join([item
+                                   for item in [current_notes, text.strip()]
+                                   if item])
         else:
             note.text = text.strip()
 
@@ -326,7 +338,8 @@ class tsunit(lisa.LISAunit):
                     location += ':' + line
                 else:
                     location = line
-            locations.append(location)
+            if location:
+                locations.append(location)
         return locations
 
     def merge(self, otherunit, overwrite=False, comments=True, authoritative=False):
@@ -502,6 +515,20 @@ class tsfile(lisa.LISAfile):
         # Qt Linguist does self-close the "location" elements though
         for e in root.xpath("//*[not(./node()) and not(text()) and not(name() = 'location')]"):
             e.text = ""
+        # For conformance with Qt output, write XML declaration with double quotes
         out.write(str('<?xml version="1.0" encoding="utf-8"?>\n').encode('utf-8'))
-        out.write(etree.tostring(root, doctype=doctype, pretty_print=True,
-                                 xml_declaration=None, encoding='utf-8'))
+        # For conformance with Qt output, post-process etree.tostring output,
+        # replacing ' with &apos; and " with &quot; in text elements
+        treestring = etree.tostring(root, doctype=doctype, pretty_print=True,
+                                    xml_declaration=False, encoding='utf-8')
+        pos = 0
+        while pos >= 0:
+            nextpos = treestring.find(b'<', pos)
+            out.write(
+                treestring[pos:nextpos].replace(b"'", b"&apos;").replace(b'"', b"&quot;")
+            )
+            pos = nextpos
+            nextpos = treestring.find(b'>', pos)
+            out.write(treestring[pos:nextpos])
+            pos = nextpos
+        out.write(treestring[pos:])
