@@ -58,6 +58,7 @@ class TxtUnit(base.TranslationUnit):
     def __init__(self, source="", **kwargs):
         """Construct the txtunit"""
         super(TxtUnit, self).__init__(source)
+        # Note that source and target are equivalent for monolingual units.
         self.source = source
         self.pretext = ""
         self.posttext = ""
@@ -67,26 +68,26 @@ class TxtUnit(base.TranslationUnit):
         """Convert a txt unit to a string"""
         return u"".join([self.pretext, self.source, self.posttext])
 
-    # Note that source and target are equivalent for monolingual units
-    def setsource(self, source):
-        """Sets the definition to the quoted value of source"""
-        self._rich_source = None
-        self._source = source
-
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
     def getsource(self):
-        """gets the unquoted source string"""
-        return self._source
-    source = property(getsource, setsource)
+        return self.source
 
-    def settarget(self, target):
+    @property
+    def target(self):
+        """gets the unquoted target string"""
+        return self.source
+
+    @target.setter
+    def target(self, target):
         """Sets the definition to the quoted value of target"""
         self._rich_target = None
         self.source = target
 
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
     def gettarget(self):
-        """gets the unquoted target string"""
-        return self.source
-    target = property(gettarget, settarget)
+        return self.target
 
     def addlocation(self, location):
         self.location.append(location)
@@ -157,8 +158,3 @@ class TxtFile(base.TranslationStore):
             if idx > 0:
                 out.write(b'\n\n')
             out.write(six.text_type(unit).encode(self.encoding))
-
-    # Deprecated on 2.0.0
-    @deprecated("Use bytes(TxtFile) instead")
-    def getoutput(self):
-        return bytes(self)
