@@ -22,12 +22,14 @@ class TestSVN(HelperTest):
     def test_add(self):
         o = get_versioned_object(self.co_path)
         self.create_files({
-            "test1.txt": "First file\n",
-            "test2.txt": "Second file\n",
+            "test1.txt": b"First file\n",
+            "test2.txt": b"Second file\n",
         })
         file_path = os.path.join(self.co_path, "test1.txt")
         o.add(os.path.join(file_path))
         o = get_versioned_object(file_path)
-        assert os.path.samefile(o.location_abs, file_path)
 
-        assert o.getcleanfile() == "First file\n"
+        # The samefile is available on Unix only, compare path only
+        assert os.path.abspath(o.location_abs) == os.path.abspath(file_path)
+
+        assert o.getcleanfile().decode('utf-8') == "First file\n"
